@@ -1,7 +1,7 @@
-from base import QuickbooksManagedObject
+from base import QuickbooksManagedObject, QuickbooksTransactionEntity
 
 
-class PaymentMethod(QuickbooksManagedObject):
+class PaymentMethod(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: The PaymentMethod entity provides the method of payment for received goods. Delete is achieved by setting the
     Active attribute to false in an entity update request; thus, making it inactive. In this type of delete,
