@@ -1,7 +1,23 @@
 from base import QuickbooksBaseObject
+from ..mixins import UpdateMixin
 
 
-class TaxService(QuickbooksBaseObject):
+class TaxRateDetails(QuickbooksBaseObject):
+    qbo_object_name = "TaxRateDetails"
+
+    def __init__(self):
+        super(TaxRateDetails, self).__init__()
+        self.TaxRateName = ""
+        self.TaxRateId = False
+        self.RateValue = ""
+        self.TaxAgencyId = ""
+        self.TaxApplicableOn = "Sales"
+
+    def __unicode__(self):
+        return self.TaxRateName
+
+
+class TaxService(QuickbooksBaseObject, UpdateMixin):
     """
     QBO definition: The TaxService endpoint allows you to perform the following actions:
 
@@ -17,26 +33,14 @@ class TaxService(QuickbooksBaseObject):
         "TaxRateDetails": TaxRateDetails
     }
 
-    qbo_object_name = "TaxService"
+    qbo_object_name = "TaxService/Taxcode"
 
     def __init__(self):
+        super(TaxService, self).__init__()
         self.TaxCode = ""
         self.TaxCodeId = ""
-        self.Active = True
+
+        self.TaxRateDetails = None
 
     def __unicode__(self):
         return self.TaxCode
-
-
-class TaxRateDetails(QuickbooksBaseObject):
-    qbo_object_name = "TaxRateDetails"
-
-    def __init__(self):
-        self.TaxRateName = ""
-        self.TaxRateId = 0
-        self.RateValue = 0
-        self.TaxAgencyId = 0
-        self.TaxApplicableOn = ""
-
-    def __unicode__(self):
-        return self.TaxRateName
\ No newline at end of file
