@@ -1,7 +1,7 @@
-from base import QuickbooksBaseObject
+from base import QuickbooksManagedObject, QuickbooksTransactionEntity, AttachableRef
 
 
-class Term(QuickbooksBaseObject):
+class Term(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: The Term entity represents the terms under which a sale is made, typically expressed in the
     form of days due after the goods are received. Optionally, a discount of the total amount may be applied if
@@ -11,17 +11,24 @@ class Term(QuickbooksBaseObject):
     date -A percent discount -An absolute discount
     """
 
-    class_dict = {}
+    class_dict = {
+        "AttachableRef": AttachableRef
+    }
     qbo_object_name = "Term"
 
     def __init__(self):
+        super(Term, self).__init__()
         self.Name = ""
         self.Type = ""
         self.DiscountPercent = 0
+        self.DueDays = 0
         self.DayOfMonthDue = 0
         self.DueNextMonthDays = 0
+        self.DiscountDays = 0
         self.DiscountDayOfMonth = 0
         self.Active = True
 
+        self.AttachableRef = None
+
     def __unicode__(self):
         return self.Name
