@@ -1,7 +1,7 @@
-from base import Ref, QuickbooksManagedObject
+from base import Ref, QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin, AttachableRef
 
 
-class TimeActivity(QuickbooksManagedObject):
+class TimeActivity(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
     """
     QBO definition: The TimeActivity entity represents a record of time worked by a vendor or employee.
     """
@@ -9,8 +9,10 @@ class TimeActivity(QuickbooksManagedObject):
         "VendorRef": Ref,
         "CustomerRef": Ref,
         "DepartmentRef": Ref,
+        "EmployeeRef": Ref,
         "ItemRef": Ref,
         "ClassRef": Ref,
+        "AttachableRef": AttachableRef
     }
 
     qbo_object_name = "TimeActivity"
@@ -18,11 +20,15 @@ class TimeActivity(QuickbooksManagedObject):
     def __init__(self):
         super(TimeActivity, self).__init__()
         self.NameOf = ""
+        self.TimeZone = ""
+        self.TxnDate = ""
         self.BillableStatus = ""
-        self.Taxable = ""
-        self.HourlyRate = ""
-        self.BreakHours = ""
-        self.BreakMinutes = ""
+        self.Taxable = False
+        self.HourlyRate = 0
+        self.Hours = 0
+        self.Minutes = 0
+        self.BreakHours = 0
+        self.BreakMinutes = 0
         self.StartTime = ""
         self.EndTime = ""
         self.Description = ""
@@ -30,5 +36,7 @@ class TimeActivity(QuickbooksManagedObject):
         self.VendorRef = None
         self.CustomerRef = None
         self.DepartmentRef = None
+        self.EmployeeRef = None
         self.ItemRef = None
         self.ClassRef = None
+        self.AttachableRef = None
\ No newline at end of file
